﻿using System;
using System.IO;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Threading.Tasks;

namespace TestClient
{
    /// <summary>
    /// 프로그램
    /// </summary>
    class Program
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region HTTP 클라이언트 구하기 - GetHTTPClient(baseAddress)

        /// <summary>
        /// HTTP 클라이언트 구하기
        /// </summary>
        /// <param name="baseAddress">기준 주소</param>
        /// <returns>HTTP 클라이언트</returns>
        private static HttpClient GetHTTPClient(string baseAddress)
        {
            HttpClient client = new HttpClient();

            client.BaseAddress = new Uri(baseAddress);

            client.DefaultRequestHeaders.Add("APIKey", "A7A54AD3-91E1-4C3A-98C6-A17E39C9EA3D");

            client.DefaultRequestHeaders.Accept.Clear();

            client.DefaultRequestHeaders.Accept.Add(new MediaTypeWithQualityHeaderValue("application/json"));

            return client;
        }

        #endregion
        #region 파일 업로드하기 (비동기) - UploadFileAsync(client, filePath)

        /// <summary>
        /// 파일 업로드하기 (비동기)
        /// </summary>
        /// <param name="client">클라이언트</param>
        /// <param name="filePath">파일 경로</param>
        /// <returns>HTTP 응답 메시지 태스크</returns>
        private static async Task<HttpResponseMessage> UploadFileAsync(HttpClient client, string filePath)
        {
            string url = string.Format("/api/File/Upload");

            MultipartFormDataContent multipartFormDataContent = new MultipartFormDataContent();

            using(FileStream fileStream = File.Open(filePath, FileMode.Open))
            {
                StreamContent streamContent = new StreamContent(fileStream);

                // "formFile"은 FileController 클래스의 Upload 메소드의 formFile 매개 변수와 일치해야 한다.
                multipartFormDataContent.Add(streamContent, "formFile", filePath);

                HttpResponseMessage responseMessage = await client.PostAsync(url, multipartFormDataContent).ConfigureAwait(false);

                return responseMessage;
            }
        }

        #endregion
        #region 프로그램 시작하기 - Main()

        /// <summary>
        /// 프로그램 시작하기
        /// </summary>
        static void Main()
        {
            using(HttpClient client = GetHTTPClient("https://localhost:44362"))
            {
                // 파일 크기는 2GB까지만 가능하다.
                UploadFileAsync(client, @"d:\sample.mp4").GetAwaiter().GetResult();
            }

            Console.WriteLine("--------------------------------------------------");
            Console.WriteLine("아무 키나 눌러 주시기 바랍니다.");
            Console.ReadKey(true);
        }

        #endregion
    }
}