﻿using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using System.IO;
using System.Threading.Tasks;

namespace TestServer.Controllers
{
    /// <summary>
    /// 파일 컨트롤러
    /// </summary>
    [Route("api/[controller]/[action]")]
    [ApiController]
    [APIKey]
    public class FileController : ControllerBase
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 업로드하기 - Upload(formFile)

        /// <summary>
        /// 업로드하기
        /// </summary>
        /// <param name="formFile">폼 파일</param>
        /// <returns>액션 결과 태스크</returns>
        [HttpPost]
        [RequestFormLimits(MultipartBodyLengthLimit = 2147483648L)]
        public async Task<IActionResult> Upload([FromForm]IFormFile formFile)
        {
            string uploadFileDirectoryPath = "d:\\DOWNLOAD";

            if(!Directory.Exists(uploadFileDirectoryPath))
            {
                Directory.CreateDirectory(uploadFileDirectoryPath);
            }

            FileInfo sourceFileInfo = new FileInfo(formFile.FileName);

            string targetFilePath = Path.Combine(uploadFileDirectoryPath, sourceFileInfo.Name);

            if(!System.IO.File.Exists(targetFilePath))
            {
                using(FileStream targetStream = new FileStream(targetFilePath, FileMode.Create))
                {
                    await formFile.CopyToAsync(targetStream);
                }

                return new JsonResult(new { FileName = sourceFileInfo.Name });
            }

            // 파일이 존재하는 경우 잘못된 요청을 반환한다.
            return BadRequest();
        }

        #endregion
    }
}